#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microlens-th
version:              0.4.3.17
visibility:           public
id:                   microlens-th-0.4.3.17-1JCZcjTuCbDB2Q9keDntvT
key:                  microlens-th-0.4.3.17-1JCZcjTuCbDB2Q9keDntvT
license:              BSD-3-Clause
maintainer:           Steven Fontanella <steven.fontanella@gmail.com>
author:               Eric Mertens, Edward Kmett, Artyom Kazak
homepage:             http://github.com/stevenfontanella/microlens
synopsis:             Automatic generation of record lenses for microlens
description:
    This package lets you automatically generate lenses for data types; code was extracted from the lens package, and therefore generated lenses are fully compatible with ones generated by lens (and can be used both from lens and microlens).

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/stevenfontanella/microlens#readme on Github>.

category:             Data, Lenses
abi:                  6ed750df8beaee8f33ce4e477eb61e06
exposed:              True
exposed-modules:      Lens.Micro.TH Lens.Micro.TH.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/microlens-th-0.4.3.17
library-dirs:         /usr/lib/ghc-9.6.6/site-local/microlens-th-0.4.3.17
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/microlens-th-0.4.3.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microlens-th
hs-libraries:         HSmicrolens-th-0.4.3.17-1JCZcjTuCbDB2Q9keDntvT
depends:
    base-4.18.2.1 containers-0.6.7
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3 template-haskell-2.20.0.0
    th-abstraction-0.6.0.0-6nwiZFs5BlM71phLjoyZV3 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-microlens-th/html/microlens-th.haddock

haddock-html:         /usr/share/doc/haskell-microlens-th/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

